# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [## [0.2.11]]

## [0.2.10]

- [schedule disconnects instead of continually running -- basnijholt/aiokef@8732ce7](https://github.com/basnijholt/aiokef/commit/8732ce7c5f68ae698f37bb02a63b0f23ec337a23)
